
Input Files
===========

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   projections
   commodities
   technodata
   technodata_timeslices
   commodities_io
   existing_capacity
   agents
   correlation_files


Indices and tables
------------------


- :ref:`genindex`
- :ref:`modindex`
- :ref:`search`
